from __future__ import absolute_import
from __future__ import division
from __future__ import print_function


__all__ = ['mma']


def mma():
    raise NotImplementedError


# ==============================================================================
# Main
# ==============================================================================

if __name__ == "__main__":
    pass
